#!/usr/bin/env python

import datetime
import re

from mako.template import Template

from qlbr import TZ
from qlbr.models import Task


tasks = {}
for task in Task.objects.iterator():
    bugid = task.bug.bug_id
    report_task = {
        'title': task.bug.title,
        'taglist': task.bug.tag_list,
        'date_created': task.date_created.isoformat(),
        'age': (datetime.datetime.now(TZ) - task.date_created).days,
        'importance': task.importance,
        'status': task.status,
        'web_link': task.web_link,
        'duplicate_link': '',
        'owner': task.owner.display_name,
        'triaged': task.triaged
    }
    dupe_of = task.bug.duplicate_of
    if dupe_of:
        report_task['duplicate_link'] = ('<a href="{}">{}</a>'
                                         .format(task.web_link, bugid))
        report_task['owner'] += ' (dup)'
        bugid = dupe_of.bug_id
        report_task['web_link'] = dupe_of.web_link
        report_task['triaged'] = dupe_of.triaged

    # Pilfered from collect-bug-data in lp:arsenal
    m = re.search('(\S+)\s\(.*\)', task.bug_target_name)
    if m is not None:
        report_task['target'] = m.group(1)
    else:
        report_task['target'] = task.bug_target_name
    m = re.search('(\S+)\s\(.*\)', task.bug_target_display_name)
    if m is not None:
        report_task['target_display_name'] = m.group(1)
    else:
        report_task['target_display_name'] = task.bug_target_display_name

    report_task['target'] = report_task['target'].replace('.', '')
    if task.assignee:
        report_task['assignee'] = task.assignee.display_name
    else:
        report_task['assignee'] = 'Unassigned'
    if bugid not in tasks:
        tasks[bugid] = []
    tasks[bugid].append(report_task)

template = Template(filename='qa-default.mako')
open('test.html', 'w').write(template.render(
    report_title='Test',
    tasks=tasks,
    timestamp=datetime.datetime.now().isoformat(),
    datefilter=True
))
